import { stackedAreaChart } from './stackedAreaChart';

const svg = d3.select(document.body).append('svg');
const gigatons = str => (+str) / 1000;

var parseRow = d => {
  d.date = d.date;
  d.hubei = d.hubei;
  d.relative = d.relative;
  d.social = d.social;
  return d;
};
  
d3.csv('data.csv', parseRow, data => {
  data.forEach(d => {
      d.date = new Date(d.date);
      d.hubei = +d.hubei;
      d.relative = +d.relative;
      d.social = +d.social;
      d.public = +d.public;
    });
  
  const render = () => {
    const width = document.body.clientWidth;
    const height = document.body.clientHeight;
    
    svg.attr('width', width).attr('height', height);
    
    let g = svg.selectAll('g').data([null]);
    g = g.enter().append('g').merge(g);
    
    stackedAreaChart(g, {
      data,
      keys: ["hubei", "relative", "social", "public"],
      width,
      height,
      xValue: d => d.date,
      colorScale: d3.scaleOrdinal(d3.schemeDark2),
      margin: { top: 10, right: 20, bottom: 40, left: 57 },
      yAxisTitle: 'CO2 Emissions (Gigatons per Year)',
      yAxisTitleOffset: -26
    });
  };
  render();
  
  window.addEventListener('resize', render);
});